#
# Makefile Template for Tessy
# Compiler: IAR MSP430
# Debugger: IAR C-SPY Simulator
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LIBRARY               :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# TARGET_INSTALL_PATH   :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef


TESSY_SYS_DOS   := $(shell ts_pathname -s $(TESSY_SYS))
IAR_HOME        := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
TS_NAME         := TS_CSPY

all    : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.d43

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE := $(TESSY_SYS)/make/master_cspy_gnu_i386.mk
S_COMM_MAKE := $(TESSY_SYS)/src/comm/comm_cspy_iar_msp430.mk


#
# SLAVE
# (You may change these settings to use your own compiler/linker options)
#
S_COMP_OPTIONS := -e -On --no_cse --no_unroll --no_inline --no_code_motion --debug --dlib_config "$(CONFIG_HEADER)" \
                  -DTESSY -DTS_SLAVE -DTS_CSPY $(TESSY_MAKE_SILENT) -DTS_MSP430 -DTS_HAVE_FLOAT64 -DTS_HAVE_INT64

S_LINK_OPTIONS := -w -D_STACK_SIZE=50 -rt -e_small_write=_formatted_write -e_medium_read=_formatted_read \
                  -D_HEAP_SIZE=50 -D_DATA16_HEAP_SIZE=50 -D_DATA20_HEAP_SIZE=50 -s __program_start \
                  -I$(IAR_HOME)\lib\clib -f $(IAR_HOME)\config\multiplier.xcl -f "$(LINKER_FILE)" "$(LIBRARY)"

S_INCLUDES     := -I$(IAR_HOME)\INC\ -I$(IAR_HOME)\INC\DLIB -I$(IAR_HOME)\LIB\DLIB -I$(TESSY_SYS_DOS)\include\tessy\comm\ -I$(MODULE_PATH_DOS)\

S_CC           := $(IAR_HOME)\bin\icc430
S_LINK         := $(IAR_HOME)\bin\xlink
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.r43
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.r43

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) -o $@ $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################


# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.r43 : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.d43 : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.r43 \
															$(S_SRC_OBJECTS) \
															$(S_UC_OBJECT) \
															$(S_STUB_OBJECT) \
															$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.r43 $(S_STUB_OBJECT) $(S_UC_OBJECT) \
   $(S_SRC_OBJECTS) $(USER_LINK_OPTIONS) $(S_OBJECTS) -o "$@" $(S_LINK_OPTIONS)
	@-ts_rm "$(MODULE_PATH)"/*.r43


#####################################################################
#END_TARGETS
#####################################################################












